@@ -1,6 +1,6 @@
 package HTML::LoutParser ; # Documented at the __END__.
 
-# $Id: LoutParser.pm,v 1.25 1999/08/08 15:17:13 root Exp $
+# $Id: LoutParser.pm,v 1.28 1999/09/06 18:17:06 root Exp $
 
 
 require HTML::Parser ;
@@ -8,7 +8,7 @@ use Lout ;
 use Text::Wrap ;
 
 use vars qw( $VERSION @ISA ) ;
-$VERSION = '1.02' ;
+$VERSION = '1.05' ;
 
 @ISA = qw( HTML::Parser ) ;
 
@@ -183,7 +183,7 @@ sub start {
         }
         if( $tag eq 'i' or 
             $tag eq 'cite' or
-            $tag =~ /^em(phasis)?$/o ) {
+            $tag =~ /^em(?:phasis)?$/o ) {
             print "{}\@I {" ;
             last CASE ;
         }
@@ -258,11 +258,14 @@ sub start {
             last CASE ;
         }
         if( $tag eq 'li' or $tag eq 'dt' ) {
-            if( ${$self->{LIST}}[$#{$self->{LIST}}] > 0 ) {
+            if( defined ${$self->{LIST}}[$#{$self->{LIST}}] and
+                        ${$self->{LIST}}[$#{$self->{LIST}}] > 0 ) {
                 print "}" ;
                 ${$self->{LIST}}[$#{$self->{LIST}}]-- ;
             }
             print "\n\@ListItem {" ;
+            push @{$self->{LIST}}, 0 
+            unless defined ${$self->{LIST}}[$#{$self->{LIST}}] ;
             ${$self->{LIST}}[$#{$self->{LIST}}]++ ;
             last CASE ;
         }
@@ -348,22 +351,22 @@ sub end {
             # No action required.
             last CASE ;
         }
-        if( $tag eq 'center'         or 
-            $tag eq 'pre'            or
-            $tag =~ /^[abiu]$/o      or 
-            $tag =~ /^su[bp]$/o      or
-            $tag eq 'strong'         or 
-            $tag =~ /^em(phasis)?$/o or
-            $tag eq 'kbd'            or 
-            $tag eq 'tt'             or 
-            $tag eq 'dd'             or 
-            $tag eq 'dl'             or 
-            $tag eq 'code'           or
-            $tag =~ /^h[1-6]$/o      or 
-            $tag eq 'font'           or
-            $tag eq 'cite'           or
-            $tag eq 'blockquote'     or
-            $tag eq 'title'
+        if( $tag eq 'center'           or 
+            $tag eq 'pre'              or
+            $tag eq 'strong'           or 
+            $tag eq 'kbd'              or 
+            $tag eq 'tt'               or 
+            $tag eq 'dd'               or 
+            $tag eq 'dl'               or 
+            $tag eq 'code'             or
+            $tag eq 'font'             or
+            $tag eq 'cite'             or
+            $tag eq 'blockquote'       or
+            $tag eq 'title'            or
+            $tag =~ /^[abiu]$/o        or 
+            $tag =~ /^su[bp]$/o        or
+            $tag =~ /^em(?:phasis)?$/o or
+            $tag =~ /^h[1-6]$/o        
             ) {
             print "}\n" ;
             last CASE ;
@@ -529,6 +532,8 @@ If you have something like "E<lt>IE<gt>thisE<lt>/IE<gt>." it may become "{}@I
 
 1999/08/08  Changed licence to LGPL.
 
+1999/09/04  Tiny fixes.
+
 =head1 AUTHOR
 
 Mark Summerfield. I can be contacted as <summer@chest.ac.uk> -
